@@ -1,6 +1,6 @@
 from django.contrib import admin
 
 class AddressAdmin(admin.ModelAdmin):
-    list_display = ['address', 'computed_address', 'latitude', 'longtitude', 'geocode_error']
+    list_display = ['address', 'computed_address', 'latitude', 'longitude', 'geocode_error']
     list_filter = ['geocode_error']
     search_fields = ['address']
